<?php

namespace Drupal\seeds_toolbar;

use Drupal\Core\Url;

class SeedsManager {

  protected $menu_link_plugin_manager;
  protected $menu_link_tree;
  protected $language_manager;
  protected $access_manager;
  protected $entityTypeManager;

  public function __construct($menu_link_plugin_manager, $menu_link_tree, $language_manager, $access_manager, $entity_type_manager) {
    $this->menu_link_plugin_manager = $menu_link_plugin_manager;
    $this->menu_link_tree = $menu_link_tree;
    $this->language_manager = $language_manager;
    $this->access_manager = $access_manager;
    $this->entityTypeManager = $entity_type_manager;
  }

  public function buildContentMenu() {
    return $this->buildMenu('node_type', 'node.add');
  }

  public function buildBlockMenu() {
    return $this->buildMenu('block_content_type', 'block_content.add_form');
  }

  public function buildTaxonomyMenu() {
    return $this->buildMenu('taxonomy_vocabulary', 'entity.taxonomy_term.add_form');
  }

  private function buildMenu($entity_type, $route) {
    $entities = $this->entityTypeManager->getStorage($entity_type)->loadMultiple();
    $items = [];
    foreach ($entities as $entity) {
      $id = $entity->id();
      $url = Url::fromRoute($route, [$entity_type => $id]);
      if ($this->userHasAccess($url)) {
        $items[$id]['url'] = $url;
        $items[$id]['title'] = $entity->label();
      }
    }
    if (empty($items)) {
      return [];
    } else {
      return [
        '#menu_name' => $type . '-add-menu',
        '#items' => $items,
        '#theme' => 'menu',
      ];
    }
  }

  private function userHasAccess($url) {
    $current_user = \Drupal::currentUser();
    return $url->access($current_user);
  }

  public function getDirection() {
    $dir = $this->language_manager->getCurrentLanguage()->getDirection();
    return ($dir == 'ltr') ? 'left' : 'right';
  }

  public static function sortTabs(array $items, array $first_tabs) {
    foreach ($items as $id => &$item) {
      if (in_array($id, $first_tabs)) {
        $item['#weight'] = array_search($id, $first_tabs);
      } else if ($id == 'admin_toolbar_tools') {
        // Always put admin_toolbar_tools at the last tab.
        $item['#weight'] = 1000;
      } else {
        $item['#weight'] = count($first_tabs) + $id;
      }
    }
    return $items;
  }
}
